@@ -93,6 +93,26 @@ def get_spark(scale=0, queue=None):
             .enableHiveSupport()
             .getOrCreate()
         )
+    elif scale in [5, 6, 7, 8]:
+        spark = (
+            SparkSession.builder.config("spark.app.name", app_name)
+            .config("spark.driver.memory", "8g")
+            .config("spark.executor.memory", f"{2 ** scale}g")
+            .config("spark.executor.instances", "32")
+            .config("spark.driver.maxResultSize", "8g")
+            .config("spark.rpc.message.maxSize", "1024")
+            .config("spark.yarn.queue", queue)
+            .config("spark.ui.enabled", "false")
+            .config("spark.port.maxRetries", "128")
+            .config("spark.executorEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
+            .config(
+                "spark.jars",
+                "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar",
+            )
+            .enableHiveSupport()
+            .getOrCreate()
+        )
     else:
         spark = (
             SparkSession.builder.config("spark.app.name", app_name)
@@ -110,7 +130,7 @@ def get_spark(scale=0, queue=None):
             .config("spark.yarn.appMasterEnv.ARROW_PRE_0_15_IPC_FORMAT", "1")
             .config(
                 "spark.jars",
-                "gs://external_libs/spark/jars/spark-bigquery-with-dependencies_2.11-0.16.1.jar",
+                "hdfs:///jars/spark-bigquery-with-dependencies_2.11-0.17.3.jar",
             )
             .enableHiveSupport()
             .getOrCreate()
